@@ -415,6 +415,8 @@ soup_uri_to_string (SoupURI *uri, gboolean just_path_and_query)
 	GString *str;
 	char *return_result;
 
+	g_return_val_if_fail (uri != NULL, NULL);
+
 	/* IF YOU CHANGE ANYTHING IN THIS FUNCTION, RUN
 	 * tests/uri-parsing AFTERWARD.
 	 */
@@ -422,7 +424,7 @@ soup_uri_to_string (SoupURI *uri, gboolean just_path_and_query)
 	str = g_string_sized_new (20);
 
 	if (uri->scheme && !just_path_and_query)
-		g_string_sprintfa (str, "%s:", uri->scheme);
+		g_string_append_printf (str, "%s:", uri->scheme);
 	if (uri->host && !just_path_and_query) {
 		g_string_append (str, "//");
 		if (uri->user) {
